@@ -119,6 +119,14 @@ class AmplifyBackendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client/#clone_backend)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amplifybackend.html#AmplifyBackend.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client/#close)
+        """
+
     def create_backend(
         self,
         *,
@@ -140,7 +148,7 @@ class AmplifyBackendClient(BaseClient):
         *,
         AppId: str,
         BackendEnvironmentName: str,
-        ResourceConfig: "BackendAPIResourceConfigTypeDef",
+        ResourceConfig: BackendAPIResourceConfigTypeDef,
         ResourceName: str
     ) -> CreateBackendAPIResponseTypeDef:
         """
@@ -155,7 +163,7 @@ class AmplifyBackendClient(BaseClient):
         *,
         AppId: str,
         BackendEnvironmentName: str,
-        ResourceConfig: "CreateBackendAuthResourceConfigTypeDef",
+        ResourceConfig: CreateBackendAuthResourceConfigTypeDef,
         ResourceName: str
     ) -> CreateBackendAuthResponseTypeDef:
         """
@@ -180,7 +188,7 @@ class AmplifyBackendClient(BaseClient):
         *,
         AppId: str,
         BackendEnvironmentName: str,
-        ResourceConfig: "CreateBackendStorageResourceConfigTypeDef",
+        ResourceConfig: CreateBackendStorageResourceConfigTypeDef,
         ResourceName: str
     ) -> CreateBackendStorageResponseTypeDef:
         """
@@ -215,7 +223,7 @@ class AmplifyBackendClient(BaseClient):
         AppId: str,
         BackendEnvironmentName: str,
         ResourceName: str,
-        ResourceConfig: "BackendAPIResourceConfigTypeDef" = ...
+        ResourceConfig: BackendAPIResourceConfigTypeDef = ...
     ) -> DeleteBackendAPIResponseTypeDef:
         """
         Deletes an existing backend API resource.
@@ -297,7 +305,7 @@ class AmplifyBackendClient(BaseClient):
         AppId: str,
         BackendEnvironmentName: str,
         ResourceName: str,
-        ResourceConfig: "BackendAPIResourceConfigTypeDef" = ...
+        ResourceConfig: BackendAPIResourceConfigTypeDef = ...
     ) -> GetBackendAPIResponseTypeDef:
         """
         Gets the details for a backend API.
@@ -436,7 +444,7 @@ class AmplifyBackendClient(BaseClient):
         AppId: str,
         BackendEnvironmentName: str,
         ResourceName: str,
-        ResourceConfig: "BackendAPIResourceConfigTypeDef" = ...
+        ResourceConfig: BackendAPIResourceConfigTypeDef = ...
     ) -> UpdateBackendAPIResponseTypeDef:
         """
         Updates an existing backend API resource.
@@ -450,7 +458,7 @@ class AmplifyBackendClient(BaseClient):
         *,
         AppId: str,
         BackendEnvironmentName: str,
-        ResourceConfig: "UpdateBackendAuthResourceConfigTypeDef",
+        ResourceConfig: UpdateBackendAuthResourceConfigTypeDef,
         ResourceName: str
     ) -> UpdateBackendAuthResponseTypeDef:
         """
@@ -461,7 +469,7 @@ class AmplifyBackendClient(BaseClient):
         """
 
     def update_backend_config(
-        self, *, AppId: str, LoginAuthConfig: "LoginAuthConfigReqObjTypeDef" = ...
+        self, *, AppId: str, LoginAuthConfig: LoginAuthConfigReqObjTypeDef = ...
     ) -> UpdateBackendConfigResponseTypeDef:
         """
         Updates the AWS resources required to access the Amplify Admin UI.
@@ -491,7 +499,7 @@ class AmplifyBackendClient(BaseClient):
         *,
         AppId: str,
         BackendEnvironmentName: str,
-        ResourceConfig: "UpdateBackendStorageResourceConfigTypeDef",
+        ResourceConfig: UpdateBackendStorageResourceConfigTypeDef,
         ResourceName: str
     ) -> UpdateBackendStorageResponseTypeDef:
         """
